@@ -22,7 +22,7 @@
 
 #include "includes.h"
 #include "data.h"
-#include "sched.h"
+#include "scheduler.h"
 #include "text.h"
 
 
@@ -57,7 +57,7 @@ private:
 	wofstream file;
 	ToDo& todo;
 	iToDo* i;
-	char path[128];
+	char path[256];
 
 	void _save();
 	void amp(wstring& str);
