@@ -1,6 +1,6 @@
 
 /*************************************************************************
- * Copyright (C) 2007-2012 Ruben Pollan Bella <meskio@sindominio.net>    *
+ * Copyright (C) 2007-2015 Ruben Pollan Bella <meskio@sindominio.net>    *
  *                                                                       *
  *  This file is part of TuDu.                                           *
  *                                                                       *
@@ -343,13 +343,25 @@ void Screen::drawTitle(int line, int depth, wstring& title, int startLine)
 {
 	int lines, cols;
 	wtree->_getmaxyx(lines, cols);
+	const unsigned int title_cols = wcswidth(title.c_str(), string::npos);
+	const unsigned int line_cols = cols-startTitle(depth);
+	const unsigned int title_lines = (title_cols && !(title_cols % line_cols)) ? (title_cols / line_cols)-1
+					: (title_cols / line_cols);
 
-	for (unsigned int i = startLine; i <= (title.length() / (cols-startTitle(depth))); i++)
+	int c = 0;
+	for (unsigned int i = 0; i <= title_lines; i++)
 	{
 		if ((int)(line + i) >= lines) break;
-		unsigned int lenTitleLine = cols-startTitle(depth);
-		wstring titleLine = title.substr(i*lenTitleLine,lenTitleLine);
-		wtree->_addstr(line + i, startTitle(depth), titleLine);
+
+		if ((int)i < startLine) {
+			for (unsigned int col = 0; col < line_cols; c++) {
+				col += wcwidth(title[c]);
+			}
+			continue;
+		}
+
+		wstring titleLine = title.substr(c, line_cols);
+		c += wtree->_addstr(line + i, startTitle(depth), titleLine, line_cols);
 	}
 }
 
@@ -434,7 +446,7 @@ void Screen::drawTask(int line, int depth, ToDo& t, bool isCursor)
 	/* draw category */
 	if (coor.exist[WCATEGORY])
 	{
-		wstring category = t.getCategoriesStr().substr(0, config.getCategoryLength());
+		wstring category = t.getCategoriesStr();
 		if (isCursor)
 			wcategory->_attron(COLOR_SELECTED);
 		else
@@ -442,7 +454,7 @@ void Screen::drawTask(int line, int depth, ToDo& t, bool isCursor)
 		if (!category.empty())
 		{
 			wcategory->_move(line, 0);
-			wcategory->_addstr(category);
+			wcategory->_addstr(category, config.getCategoryLength());
 		}
 		if (isCursor)
 			wcategory->_attroff(COLOR_SELECTED);
@@ -536,9 +548,9 @@ void Screen::drawSched(Sched &sched, pToDo cursor)
 		if (cursor == (*i))
 			wschedule->_attron(COLOR_SELECTED);
 		wschedule->_addstr("    ");
-		wstring title = (*i)->getTitle().substr(0,coor.coor[WSCHEDULE].cols-4);
-		wschedule->_addstr(title);
-		if (title.length() < (size_t)coor.coor[WSCHEDULE].cols-4)
+		wstring title = (*i)->getTitle();
+		int printed_chars = wschedule->_addstr(title, coor.coor[WSCHEDULE].cols-4);
+		if ((int)title.length() == printed_chars)
 			wschedule->_addstr("\n");
 		line++;
 	}
@@ -759,12 +771,14 @@ int Screen::treeLines()
 
 int Screen::taskLines(int depth, ToDo &t)
 {
-	int titleLength = t.getTitle().length();
-	int titleLines = (titleLength / (coor.coor[WTREE].cols-startTitle(depth))) + 1;
+	unsigned int title_cols = wcswidth(t.getTitle().c_str(), string::npos);
+	if (title_cols==(unsigned int)-1) // nonprintable wide character occurs among these characters
+			title_cols=0;
+	int title_lines = (title_cols / (coor.coor[WTREE].cols-startTitle(depth))) + 1;
 	
-	if (titleLength && !(titleLength % (coor.coor[WTREE].cols-startTitle(depth))))
-			titleLines -= 1;
-	return titleLines;
+	if (title_cols && !(title_cols % (coor.coor[WTREE].cols-startTitle(depth))))
+			title_lines -= 1;
+	return title_lines;
 }
 
 Editor::return_t Screen::searchText(wstring& pattern, int cursorPos)
